@@ -56,7 +56,7 @@ macro_rules! newtype_index {
         }
     };
     ($vis:vis $type:ident) => {
-        $crate::newtype_index!($vis struct $type {})
+        $crate::newtype_index!($vis struct $type {});
     };
 }
 
